declare module "internals" {
    export const block: unique symbol;
    export const repeatCtx: unique symbol;
    export function requestIdleCallback(cb: any, ...args: any[]): NodeJS.Timeout;
    export const internals: unique symbol;
    export const CREATE: unique symbol;
    export const RENDER: unique symbol;
    export const ADDED: unique symbol;
    export const REMOVED: unique symbol;
    export const debug: unique symbol;
}
declare module "utils" {
    export function forceUpdate(target: typeof import("component"), ...keys: string[][]): void;
    export { requestIdleCallback };
    export function findCtx(t: Node | Element | null): any;
    export function isForcedUpdate(t: any): boolean;
    export function markFlush(t: any, flush: any): WeakMap<object, any>;
    export function dashToCamel(dash: string): string;
    export function syntaxMethod(): RegExp;
    export function lazyQueue(queue: Set<Function> | Array<Function>, timeout?: number | undefined): void;
    export function normalize(html: string): string;
    export function memoize(fn: Function): (str: any) => any;
    export function createFunction(...args: any[]): any;
    export function NOOP(): undefined;
    import { requestIdleCallback } from "internals";
}
declare module "expression" {
    export const parse: (str: any) => any;
    export type ParseResult = {
        paths: string[];
        expressions: string[];
    };
}
declare module "enhance" {
    export const DirectiveRegistry: Registry;
    export const PluginRegistry: PluginRegistryClass;
    class Registry {
        add(addon: any, priority?: boolean): void;
        getAll(): any[];
        [addons]: any[];
    }
    class PluginRegistryClass extends Registry {
        exec(...params: any[]): void;
    }
    const addons: unique symbol;
    export {};
}
declare module "dom" {
    export function createBind(source: any, target: any, property: any, execution: any): () => void;
    export function removeBindings(source: any, target: any, property?: string): void;
    export function processDOM(scope: any, dom: Node): {
        flush: (...props: any[]) => void;
        clear: () => void;
        bounds: Set<any>;
    };
}
declare module "component" {
    export default class Component extends HTMLElement {
        static template: string;
        static useShadow: boolean;
        static element(tag: string, template: string, base: typeof Component): void;
        onBeforeCreated(): void;
        onCreated(): void;
        onAdded(): void;
        onRemoved(): void;
        onRender(): void;
        protected connectedCallback(): void;
        disconnectedCallback(): void;
        [LC_Create](): any;
        [LC_Render](): void;
        [internals]: {
            created: boolean;
        };
    }
    const LC_Create: unique symbol;
    const LC_Render: unique symbol;
    import { internals } from "internals";
    export {};
}
declare module "index" {
    export * as Utils from "utils";
    export namespace Phase {
        export { ADDED };
        export { CREATE };
        export { RENDER };
        export { REMOVED };
    }
    export namespace Internals {
        export { repeatCtx };
        export { internals };
        export { block };
        export { requestIdleCallback };
    }
    import Component from "component";
    import { DirectiveRegistry } from "enhance";
    import { PluginRegistry } from "enhance";
    import { processDOM } from "dom";
    import { removeBindings } from "dom";
    import { createBind } from "dom";
    import { ADDED } from "internals";
    import { CREATE } from "internals";
    import { RENDER } from "internals";
    import { REMOVED } from "internals";
    import { repeatCtx } from "internals";
    import { internals } from "internals";
    import { block } from "internals";
    import { requestIdleCallback } from "internals";
    export { Component as Slim, Component, DirectiveRegistry, PluginRegistry, processDOM, removeBindings, createBind };
}
type NodeProcessInfo = {
    scopeNode: any | Element;
    targetNode: Element;
    attribute: Attr;
    attributeName: string;
    attributeValue: string | null;
    expression: string;
    context: any;
    props: string[];
};
type NodeProcessResult = {
    update: (value: any) => any;
    removeAttribute?: boolean | undefined;
    removeNode?: boolean | undefined;
};
type AttributeTest = (attr: Attr, nodeName: string, nodeValue: string | null) => any;
type NodeProcessor = (info: NodeProcessInfo) => NodeProcessResult;
type Directive = {
    attribute: AttributeTest;
    process: NodeProcessor;
};
